>From 450c532120ba617b207c1dc0d7c35b2cb7ab58f1 Mon Sep 17 00:00:00 2001
From: Sergio Ammirata <sergio@ammirata.net>
Date: Wed, 13 Mar 2019 20:08:37 -0400
Subject: [PATCH 3/4] Qt: sout: Add rist output option

---
 .../gui/qt/components/sout/sout_widgets.cpp   | 53 +++++++++++++++++++
 .../gui/qt/components/sout/sout_widgets.hpp   | 13 +++++
 modules/gui/qt/dialogs/sout.cpp               | 11 ++--
 3 files changed, 74 insertions(+), 3 deletions(-)

diff --git a/modules/gui/qt/components/sout/sout_widgets.cpp b/modules/gui/qt/components/sout/sout_widgets.cpp
index a6793e9243..4f7f1caa11 100644
--- a/modules/gui/qt/components/sout/sout_widgets.cpp
+++ b/modules/gui/qt/components/sout/sout_widgets.cpp
@@ -359,6 +359,59 @@ QString UDPDestBox::getMRL( const QString& mux )
     return m.getMrl();
 }
 
+RISTDestBox::RISTDestBox( QWidget *_parent, const char *_mux )
+    : VirtualDestBox( _parent ), mux( qfu(_mux) )
+{
+    label->setText( qtr( "This module outputs the stream using the RIST protocol (TR06).") );
+
+    QLabel *RISTAddressLabel = new QLabel( qtr("Destination Address"), this );
+    RISTAddress = new QLineEdit(this);
+    layout->addWidget(RISTAddressLabel, 1, 0, 1, 1);
+    layout->addWidget(RISTAddress, 1, 1, 1, 1);
+
+    QLabel *RISTPortLabel = new QLabel( qtr("Destination Port"), this );
+    RISTPort = new QSpinBox(this);
+    RISTPort->setMaximumSize(QSize(90, 16777215));
+    RISTPort->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
+    RISTPort->setMinimum(1);
+    RISTPort->setMaximum(65535);
+    RISTPort->setValue(1968);
+    layout->addWidget(RISTPortLabel, 2, 0, 1, 1);
+    layout->addWidget(RISTPort, 2, 1, 1, 1);
+
+    QLabel *RISTNameLabel = new QLabel( qtr("Stream Name"), this );
+    RISTName = new QLineEdit(this);
+    layout->addWidget(RISTNameLabel, 3, 0, 1, 1);
+    layout->addWidget(RISTName, 3, 1, 1, 1);
+
+    CT( RISTAddress );
+    CS( RISTPort );
+    CT( RISTName );
+}
+
+QString RISTDestBox::getMRL( const QString& )
+{
+    QString addr = RISTAddress->text();
+    QString name = RISTName->text();
+
+    if( addr.isEmpty() ) return qfu("");
+    QString destination = addr + ":" + QString::number(RISTPort->value());
+    SoutMrl m;
+    m.begin( "std" );
+    if( !name.isEmpty() )
+    {
+        m.option( "access", "rist{stream-name=" + name + "}" );
+    }
+    else
+    {
+        m.option( "access", "rist" );
+    }
+    m.option( "mux", "ts" );
+    m.option( "dst", destination );
+    m.end();
+
+    return m.getMrl();
+}
 
 
 RTPDestBox::RTPDestBox( QWidget *_parent, const char *_mux )
diff --git a/modules/gui/qt/components/sout/sout_widgets.hpp b/modules/gui/qt/components/sout/sout_widgets.hpp
index 5b9496c83a..1f1146671f 100644
--- a/modules/gui/qt/components/sout/sout_widgets.hpp
+++ b/modules/gui/qt/components/sout/sout_widgets.hpp
@@ -117,6 +117,19 @@ class UDPDestBox: public VirtualDestBox
         QSpinBox *UDPPort;
 };
 
+class RISTDestBox: public VirtualDestBox
+{
+    Q_OBJECT
+    public:
+        RISTDestBox( QWidget *_parent = NULL, const char *mux = NULL );
+        QString getMRL( const QString& ) Q_DECL_OVERRIDE;
+    private:
+        QLineEdit *RISTAddress;
+        QSpinBox *RISTPort;
+        QLineEdit *RISTName;
+        QString mux;
+};
+
 class RTPDestBox: public VirtualDestBox
 {
     Q_OBJECT
diff --git a/modules/gui/qt/dialogs/sout.cpp b/modules/gui/qt/dialogs/sout.cpp
index 8c2be69e23..7b9a4ee5bf 100644
--- a/modules/gui/qt/dialogs/sout.cpp
+++ b/modules/gui/qt/dialogs/sout.cpp
@@ -69,6 +69,7 @@ SoutDialog::SoutDialog( QWidget *parent, intf_thread_t *_p_intf, const QString&
     ui.destBox->addItem( "HTTP" );
     ui.destBox->addItem( "MS-WMSP (MMSH)" );
     ui.destBox->addItem( "RTSP" );
+    ui.destBox->addItem( "RIST / MPEG Transport Stream" );
     ui.destBox->addItem( "RTP / MPEG Transport Stream" );
     ui.destBox->addItem( "RTP Audio/Video Profile" );
     ui.destBox->addItem( "UDP (legacy)" );
@@ -132,18 +133,22 @@ void SoutDialog::addDest( )
             caption = qfu( "RTSP" );
             break;
         case 4:
+            db = new RISTDestBox( this, "ts" );
+            caption = "RIST/TS";
+            break;
+        case 5:
             db = new RTPDestBox( this, "ts" );
             caption = "RTP/TS";
             break;
-        case 5:
+        case 6:
             db = new RTPDestBox( this );
             caption = "RTP/AVP";
             break;
-        case 6:
+        case 7:
             db = new UDPDestBox( this );
             caption = "UDP";
             break;
-        case 7:
+        case 8:
             db = new ICEDestBox( this );
             caption = "Icecast";
             break;
-- 
2.17.1

